@@ -3,7 +3,7 @@ use warnings;
 package App::Nopaste::Service;
 # ABSTRACT: base class for nopaste services
 
-our $VERSION = '1.006';
+our $VERSION = '1.007';
 
 use WWW::Mechanize;
 
@@ -109,12 +109,12 @@ App::Nopaste::Service - base class for nopaste services
 
 =head1 VERSION
 
-version 1.006
+version 1.007
 
 =head1 SYNOPSIS
 
     package App::Nopaste::Service::Shadowcat;
-    use base 'App::Nopaste::Service';
+    use parent 'App::Nopaste::Service';
 
     sub uri { "http://paste.scsys.co.uk/" }
 
