@@ -3,9 +3,9 @@ use warnings;
 package App::Nopaste::Service::Mojopaste;
 # ABSTRACT: Service provider for mojopaste
 
-our $VERSION = '1.006';
+our $VERSION = '1.007';
 
-use base 'App::Nopaste::Service';
+use parent 'App::Nopaste::Service';
 
 sub uri { $ENV{NOPASTE_MOJOPASTE_WEBPATH} || 'https://ssl.thorsen.pm/paste' }
 
@@ -57,7 +57,7 @@ App::Nopaste::Service::Mojopaste - Service provider for mojopaste
 
 =head1 VERSION
 
-version 1.006
+version 1.007
 
 =head1 USAGE
 
