@@ -3,9 +3,9 @@ use warnings;
 package App::Nopaste::Service::Snitch;
 # ABSTRACT: Service provider for Snitch - http://nopaste.snit.ch/
 
-our $VERSION = '1.006';
+our $VERSION = '1.007';
 
-use base 'App::Nopaste::Service';
+use parent 'App::Nopaste::Service';
 
 sub available {
     my $self = shift;
@@ -29,7 +29,7 @@ App::Nopaste::Service::Snitch - Service provider for Snitch - http://nopaste.sni
 
 =head1 VERSION
 
-version 1.006
+version 1.007
 
 =head1 SUPPORT
 
