@@ -3,9 +3,9 @@ use warnings;
 package App::Nopaste::Service::Ubuntu;
 # ABSTRACT: Service provider for Ubuntu - http://paste.ubuntu.com/
 
-our $VERSION = '1.005';
+our $VERSION = '1.007';
 
-use base 'App::Nopaste::Service';
+use parent 'App::Nopaste::Service';
 
 my $languages = {
     "Plain Text"                     => "text",
@@ -248,7 +248,7 @@ App::Nopaste::Service::Ubuntu - Service provider for Ubuntu - http://paste.ubunt
 
 =head1 VERSION
 
-version 1.005
+version 1.007
 
 =for stopwords Niebur
 
