@@ -3,9 +3,9 @@ use warnings;
 package App::Nopaste::Service::ssh;
 # ABSTRACT: Copies files to your server using scp
 
-our $VERSION = '1.005';
+our $VERSION = '1.007';
 
-use base 'App::Nopaste::Service';
+use parent 'App::Nopaste::Service';
 use File::Temp;
 use File::Spec;
 use POSIX qw(strftime);
@@ -77,7 +77,7 @@ App::Nopaste::Service::ssh - Copies files to your server using scp
 
 =head1 VERSION
 
-version 1.005
+version 1.007
 
 =for stopwords dir
 
